Welcome to django-teamwork's documentation!
=============================================

django-teamwork is a Django app that offers an authorization backend with
support for per-object permissions based on combinations of Teams, Roles, and
Policies.

- `Source code on GitHub <https://github.com/lmorchard/django-teamwork>`_
- `Build status on travis-ci <http://travis-ci.org/lmorchard/django-teamwork>`_ (|build-status|)
- `Latest documentation on Read The Docs <https://django-teamwork.readthedocs.org/en/latest/>`_
  (`source <https://github.com/lmorchard/django-teamwork/tree/master/docs>`_)

.. |build-status| image:: https://secure.travis-ci.org/lmorchard/django-teamwork.png?branch=master
           :target: http://travis-ci.org/lmorchard/django-teamwork

Contents:

.. toctree::
   :maxdepth: 2

   overview
   getting_started
   usage
   contributing
   faqs
   todo

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`


.. vim:set tw=78 ai fo+=n fo-=l ft=rst:
